==> viha-5.15.tar.gz: viha-5.15/hlo-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo-takt.php";

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Henkil</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", henkiltietojen pivitys</h1>
";

taktiset_linkit();

echo "<form action=\"\" method=\"GET\">\n";

$sql_tail =
  "FROM hlo, ryhma, hlo_tila, hlo_asema
   WHERE ryhma.id = hlo.ryhma_id AND hlo_tila.id = hlo.hlo_tila_id
         AND hlo_asema.id = hlo_asema_id
         AND (hlo.paivystys_id = " . s("paivystys") . "
              OR hlo.alue_id = 2
              OR (hlo.alue_id = " . s("alue") . "
                  AND hlo.paivystys_id = 2))
   ORDER BY hlo.nimi"; 
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
echo "<p><b>Yhteens $items</b>\n";
$sql = "
SELECT hlo.id, hlo.nimi, ryhma.kutsu, hlo_tila, hlo_asema
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_bgcolor()
	. "<TH>Nimi<TH>Tila<TH>Ryhm<TH>Asema\n";
    }
    echo "    <tr>",
      "<TD>$a[nimi]",
      "<td><a href=\"hlo-takt-1.php?id=$a[id]\">$a[hlo_tila]</a>",
      "<td>$a[kutsu]",
      "<td>$a[hlo_asema]",
      "\n";
    if ((($n % $percol) == ($percol - 1)) || ($n == ($items - 1)))
      echo "  </table>\n";
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei henkiltietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-takt.php,v 1.9 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/hlo-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo-takt.php";

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Henkil</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", henkiltietojen pivitys</h1>
";

taktiset_linkit();

echo "<form action=\"\" method=\"GET\">\n";

$sql_tail =
  "FROM hlo, ryhma, hlo_tila, hlo_asema
   WHERE ryhma.id = hlo.ryhma_id AND hlo_tila.id = hlo.hlo_tila_id
         AND hlo_asema.id = hlo_asema_id
         AND (hlo.paivystys_id = " . s("paivystys") . "
              OR hlo.alue_id = 2
              OR (hlo.alue_id = " . s("alue") . "
                  AND hlo.paivystys_id = 2))
   ORDER BY hlo.nimi"; 
$columns = 2;
$items = ota_yksi("
SELECT COUNT(*)
$sql_tail
");
$percol = intval(floor(($items + $columns - 1) / $columns));
echo "<p><b>Yhteens $items</b>\n";
$sql = "
SELECT hlo.id, hlo.nimi, ryhma.kutsu, hlo_tila, hlo_asema
$sql_tail
";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table>\n
  <tr valign=top>\n
";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
	. tr_vaalsin()
	. "<TH>Nimi<TH>Tila<TH>Ryhm<TH>Asema\n";
    }
    echo "    <tr>",
      "<TD>$a[nimi]",
      "<td><a href=\"hlo-takt-1.php?id=$a[id]\">$a[hlo_tila]</a>",
      "<td>$a[kutsu]",
      "<td>$a[hlo_asema]",
      "\n";
    if ((($n % $percol) == ($percol - 1)) || ($n == ($items - 1)))
      echo "  </table>\n";
    $n ++;
  }
  echo "</TABLE>";
} else {
    echo "<P>Plop. Ei henkiltietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-takt.php,v 1.11 2009/09/29 16:09:14 riku Exp $ -->
